NAME

Imgur::API::Endpoint::Notification

DESCRIPTION

Access to the imgur Notification API Endpoint.

METHODS

notifications

Get all notifications for the user that's currently logged in

Parameters

  • new optional

    boolean - false for all notifications, true for only non-viewed notification. Default is true.

get

Returns the data about a specific notification

Parameters

  • notification required

    Notification

viewed

Marks a notification as viewed, this way it no longer shows up in the basic notification request

Parameters

  • ids optional

    To mark multiple notifications as read in one call, pass in an 'ids' parameter (omitting the 'id' parameter in the route) with the value of a comma-separated string of notification ids.

  • notification required

    Notification

SEE ALSO

https://api.imgur.com/endpoints/notification